<?php
// +----------------------------------------------------------------------+
// | Anuko Time Tracker
// +----------------------------------------------------------------------+
// | Copyright (c) Anuko International Ltd. (http://www.anuko.com)
// +----------------------------------------------------------------------+
// | LIBERAL FREEWARE LICENSE: This source code document may be used
// | by anyone for any purpose, and freely redistributed alone or in
// | combination with other software, provided that the license is obeyed.
// |
// | There are only two ways to violate the license:
// |
// | 1. To redistribute this code in source form, with the copyright
// |    notice or license removed or altered. (Distributing in compiled
// |    forms without embedded copyright notices is permitted).
// |
// | 2. To redistribute modified versions of this code in *any* form
// |    that bears insufficient indications that the modifications are
// |    not the work of the original author(s).
// |
// | This license applies to this document only, not any other software
// | that it may be combined with.
// |
// +----------------------------------------------------------------------+
// | Contributors:
// | http://www.anuko.com/time_tracker/credits.htm
// +----------------------------------------------------------------------+

// HTML elements for table header.
$style_tableHeader = 'color: #000000; font-weight: bold; background-color: #A6CCF7';
$header_start = "<tr>\n<td align=\"center\" style=\"$style_tableHeader\">";
$header_glue = "</td>\n<td align=\"center\" style=\"$style_tableHeader\">";
$header_end = "</td></tr>\n";

// HTML elements for table rows.
$table_row = "<tr%s>\n<td%s>%s</td>\n</tr>\n";
$row_glue = "</td>\n<td%s>";

// Styles for table cells.
$styleWeekend = 'background-color: #f7f7f7';
$styleBorder = 'border-top: solid #e0e0e0 1pt';

// Structure of the summary table in the end of report.
if ($includeCost) {
  $summary = "<table border=0>\n<tr>\n<td align='left'><b>%s:</b></td>\n<td align='right'><b>%s</b></td>\n</tr>\n<tr>\n<td align='left'><b>%s:</b></td>\n<td align='right'><b>%s</b></td>\n</tr>\n<tr>\n<td align='left'><b>%s:</b></td><td align='right'><b>%s</b></td>\n</tr>\n<tr>\n<td align='left'><b>%s:</b></td><td align='right'><b>%s</b></td>\n</tr>\n</table>";
} else {
  // The difference is that there is no "Total cost..." line in the end.
  $summary = "<table border=0>\n<tr>\n<td align='left'><b>%s:</b></td>\n<td align='right'><b>%s</b></td>\n</tr>\n<tr>\n<td align='left'><b>%s:</b></td>\n<td align='right'><b>%s</b></td>\n</tr>\n<tr>\n<td align='left'><b>%s:</b></td><td align='right'><b>%s</b></td>\n</tr>\n</table>";
}

// Start creating report body.
$reportBody = "<table border='0' cellpadding='4' cellspacing='0' width='100%'>\n";

// Create a header for report table.
if ($totals_only) {
  $short_header = array();
  foreach ($hkeys as $k=>$fn) {
  	if (($fn == $sort_key) || ($fn == 'duration') || ($fn == 'cost') ||
      ($bean->getAttribute('project') && ($fn == 'project')) ||
      ($bean->getAttribute('task') && ($fn == 'activity'))) $short_header[] = $header[$k];
    }
  $reportBody .= $header_start . join($header_glue, $short_header). $header_end;
} else {
  $reportBody .= $header_start . join($header_glue, $header). $header_end;
}

// Build table rows.
$prev_value = "";
$prev_date = "";

$weekend_start = 6; // Saturday by default.
$weekend_end = 0;   // Sunday by default.
if (defined('WEEKEND_START_DAY')) {
  $weekend_start = WEEKEND_START_DAY;
  $weekend_end = (WEEKEND_START_DAY + 1) % 7;
}
    
for ($i=0; $i<count($rows); $i++ ) {
	
  // Get next row.
  $row = $rows[$i];

  if(!$totals_only) {

    // Determine the style for row.
    $row_style = '';
    
    // Weekend or holiday?
    $cur_weekday = @$weekdays[$row['date']];
    $weekend = ($cur_weekday == $weekend_start || $cur_weekday == $weekend_end || in_array(date("m/d", strtotime($row['date'])), $i18n->holidays));
    if ($weekend)
      $row_style .= ' style="'.$styleWeekend.'"';
  	
    // Determine style for cells in this row.
    $cell_style = '';
    // Do we need to draw the line on top this row of cells?
    $border = $prev_value != $row['sortkey'] || $prev_date != $row['date'];
    if ($border)
      $cell_style .= ' style="'.$styleBorder.'"';
      
    // $cell_glue is styled HTML code fragment between cell data. 
    $cell_glue = sprintf($row_glue, $cell_style);
    $cell_glue_right_aligned = sprintf($row_glue, ' align="right"'.$cell_style);
      
    // Iterate through cells to build output for a single row.
    $separator = '';
	$single_row_output = '';
    foreach ($hkeys as $fn) {
      $v = $row[$fn];
      if ($fn == 'date') { $v = @$dates[$row[$fn]]; }
      if (($fn == 'user') && ($v == '') && ($sort_key == 'user')) $v = $row['sortkey'];
      if (($fn == 'project') && ($v == '') && ($sort_key == 'project')) $v = $row['sortkey'];
      if (($fn == 'task') && ($v == '') && ($sort_key == 'task')) $v = $row['sortkey'];
      if ($bean->getAttribute('chemptydays')) {
      	if (($fn == 'note') && ($v == '') && (strlen($row['duration']) == 0)) $v = $i18n->getKey('form.report.no_data');
      	if (($fn == 'project') && ($v == '') && $bean->getAttribute('project')) $v = $current_project_name;
      	if (($fn == 'task') && ($v == '') && $bean->getAttribute('task')) $v = $current_task_name;
      }
      if (!$v) $v = '&nbsp;';
      // Right-align certain columns.
      if ($fn == 'duration' || $fn == 'start' || $fn == 'finish' || $fn == 'cost')
        $separator = $cell_glue_right_aligned;
      if ($fn != 'date') {
      	$single_row_output .= $separator . $v;
      } else {
      	// Output date only for the first row for this date, otherwise print empty space.
      	$single_row_output .= $separator . ($prev_date != $row['date'] ? $v : '&nbsp;');
      }
      $separator = $cell_glue;
    }
    // Output single row now.
    $reportBody .= sprintf($table_row, $row_style, $cell_style, $single_row_output);
  	
    $prev_value = $row['sortkey'];
    $prev_date = $row['date'];
  }

  // Print subtotals.
  $separator = sprintf($row_glue, ' style="border-top: solid #e0e0e0 1pt"');
  $separator_right_aligned = sprintf($row_glue, ' align="right" style="border-top: solid #e0e0e0 1pt"');
  
  	$top_framed = ' style=\'border-top: solid #e0e0e0 1pt\'';
  	
		// subsummary block
		if((@$row['sortkey'] != @$rows[$i+1]['sortkey']) && (@$sort_key != 'date')) {

			$sep = "";
			$srow = "";
			if ($totals_only) { // "totals only" flag
				foreach($hkeys as $k=>$fn) {
					if($fn==$sort_key) {
						$srow .= $sep . @$row['sortkey'];
						$sep = sprintf($row_glue, $top_framed);
					}
					if($fn=='duration') {
						$srow .= $separator_right_aligned . @$subtotals[@$row['sortkey']]['time'];
						$sep = sprintf($row_glue, $top_framed);
					}
					if($fn=='cost') {
						$srow .= $separator_right_aligned . @$subtotals[@$row['sortkey']]['cost'];
						$sep = sprintf($row_glue, $top_framed);
					}
     				if($bean->getAttribute("project") && ($fn == 'project') && ($sort_key != 'project')) {
						$srow .= $sep . @$row['project'];
						$sep = sprintf($row_glue, $top_framed);
					}
					if ($bean->getAttribute("task") && ($fn == 'activity') && ($sort_key != 'activity')) {
						$srow .= $sep . @$row['task'];
						$sep = sprintf($row_glue, $top_framed);
					}
				}
				$reportBody .= sprintf($table_row, '', $top_framed, $srow);
			}
			else { // the rest
				foreach ($hkeys as $fn) {
					switch ($fn) {
						case 'duration':
							$srow .= $separator_right_aligned . '<b>'.@$subtotals[@$row['sortkey']]['time'].'</b>';
						break;
						case 'cost':
							$srow .= $separator_right_aligned . '<b>'.@$subtotals[@$row['sortkey']]['cost'].'</b>';
						break;
						case 'date':
							$srow .= $sep . '<b>'.$i18n->getKey("label.subtotal").':</b>';
						break;
						default:
							$srow .= $sep . '&nbsp;';
					}
					$sep = sprintf($row_glue, $top_framed);
				}
				$reportBody .= sprintf($table_row, '', $top_framed, $srow);
				$reportBody .= sprintf("<tr><td %s colspan=%d>&nbsp;</td></tr>", '', (count($fields) + $includeCost + $include_cf_1));
			}
			// reset date
			$prev_date = '';
		}
	}

	$reportBody .= sprintf("<tr><td %s colspan=%d>&nbsp;</td></tr>", $top_framed, (count($fields) + $includeCost + $include_cf_1));
	$reportBody .= "</table>\n";

// summary
    if ($total_time=="") $total_time = 0;
    $currency = $user->currency;
    $reportBody .= sprintf ($summary, $i18n->getKey('label.start_date'), $period->getBeginDate(),
    										$i18n->getKey('label.end_date'), $period->getEndDate(),
    										$i18n->getKey('label.total_hours'), $total_time,
    										$i18n->getKey('label.total_cost'), $currency." ".$total_cost);

    print $reportBody;
?>